```{include} ../README.md
:start-line: 0
:end-line: 3
```

Core schema module for tracking data provenance & data flow, independent of domain knowledge.

It is built with [SQLModel](https://sqlmodel.tiangolo.com/), which is based on [SQLAlchemy](https://www.sqlalchemy.org/) & [Pydantic](https://pydantic-docs.helpmanual.io/).

- See the tables in this module in the [API](api).
- See the [source code](https://github.com/laminlabs/lnschema-core) on GitHub.
- For changes & migrations, see the [changelog](changelog).
- For the overall schema API, see [db/lamindb.schema](https://lamin.ai/docs/db/lamindb.schema).
- For usage, see [db/guide](https://lamin.ai/docs/db/lamindb.schema).
- For basic functionality and development, see the [guide](guide) and the [notes](notes).

```{toctree}
:maxdepth: 1
:hidden:

api
guide
notes
changelog
```
